# ProductStatus

The status for a Product.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**billing_product_prices** | [**[BillingProductPrice]**](BillingProductPrice.md) | A list of billing products that are contained in this Product | [optional] 
**features** | [**[Feature]**](Feature.md) | a list of features associated with this product | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


